@@ -25,6 +25,10 @@
 #  define UWSGI_PY312
 #endif
 
+#if (PY_VERSION_HEX >= 0x030d0000)
+#  define UWSGI_PY313
+#endif
+
 #if PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION < 7
 #define HAS_NOT_PyMemoryView_FromBuffer
 #endif
@@ -41,12 +45,8 @@
 #define HAS_NO_ERRORS_IN_PyFile_FromFd
 #endif
 
-#if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION < 7
-#define HAS_NOT_PyOS_AfterFork_Child
-#endif
-
-#if PY_MAJOR_VERSION < 3
-#define HAS_NOT_PyOS_AfterFork_Child
+#if (PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION < 7) || PY_MAJOR_VERSION < 3
+#define HAS_NOT_PYOS_FORK_STABLE_API
 #endif
 
 #if PY_MAJOR_VERSION > 2
@@ -172,7 +172,15 @@ struct uwsgi_python {
 
 	char *callable;
 
-#ifdef UWSGI_PY312
+#ifdef UWSGI_PY313
+	int *current_c_recursion_remaining;
+	int *current_py_recursion_remaining;
+	struct _PyInterpreterFrame **current_frame;
+
+	int current_main_c_recursion_remaining;
+	int current_main_py_recursion_remaining;
+	struct _PyInterpreterFrame *current_main_frame;
+#elif defined UWSGI_PY312
 	int *current_c_recursion_remaining;
 	int *current_py_recursion_remaining;
 	_PyCFrame **current_frame;
