@@ -2,9 +2,10 @@ from threading import Thread
 import time
 import uwsgi
 
+
 def mess():
     while True:
-        for i in xrange(0, 100):
+        for i in range(0, 100):
             if uwsgi.ready():
                 uwsgi.signal(17)
             print(i)
